==> gwyddion_2.50.orig.tar.xz: gwyddion-2.50/modules/process/process.c <==
/* This is a GENERATED file. */
#include <glib.h>
#include <libgwymodule/gwymodule.h>

static const GwyModuleRecord* register_bundle(void);

static GwyModuleInfo module_info = {
    GWY_MODULE_ABI_VERSION | GWY_MODULE_BUNDLE_FLAG,
    (GwyModuleRegisterFunc)&register_bundle,
    NULL, NULL, NULL, NULL, NULL,
};

GWY_MODULE_QUERY(module_info)

GwyModuleInfo* _gwy_module_query__acf2d(void);
GwyModuleInfo* _gwy_module_query__angle_dist(void);
GwyModuleInfo* _gwy_module_query__arithmetic(void);
GwyModuleInfo* _gwy_module_query__averaging(void);
GwyModuleInfo* _gwy_module_query__basicops(void);
GwyModuleInfo* _gwy_module_query__bdep_synth(void);
GwyModuleInfo* _gwy_module_query__binning(void);
GwyModuleInfo* _gwy_module_query__calcoefs_load(void);
GwyModuleInfo* _gwy_module_query__calcoefs_new(void);
GwyModuleInfo* _gwy_module_query__calcoefs_simple(void);
GwyModuleInfo* _gwy_module_query__calcoefs_view(void);
GwyModuleInfo* _gwy_module_query__calibrate(void);
GwyModuleInfo* _gwy_module_query__coerce(void);
GwyModuleInfo* _gwy_module_query__col_synth(void);
GwyModuleInfo* _gwy_module_query__convolution_filter(void);
GwyModuleInfo* _gwy_module_query__convolve(void);
GwyModuleInfo* _gwy_module_query__correct_affine(void);
GwyModuleInfo* _gwy_module_query__crosscor(void);
GwyModuleInfo* _gwy_module_query__curvature(void);
GwyModuleInfo* _gwy_module_query__cwt(void);
GwyModuleInfo* _gwy_module_query__deposit_synth(void);
GwyModuleInfo* _gwy_module_query__diff_synth(void);
GwyModuleInfo* _gwy_module_query__domain_synth(void);
GwyModuleInfo* _gwy_module_query__drift(void);
GwyModuleInfo* _gwy_module_query__dwt(void);
GwyModuleInfo* _gwy_module_query__dwtanisotropy(void);
GwyModuleInfo* _gwy_module_query__edge(void);
GwyModuleInfo* _gwy_module_query__entropy(void);
GwyModuleInfo* _gwy_module_query__extend(void);
GwyModuleInfo* _gwy_module_query__extract_path(void);
GwyModuleInfo* _gwy_module_query__facet_level(void);
GwyModuleInfo* _gwy_module_query__facet_analysis(void);
GwyModuleInfo* _gwy_module_query__fbm_synth(void);
GwyModuleInfo* _gwy_module_query__fft(void);
GwyModuleInfo* _gwy_module_query__fft_filter_1d(void);
GwyModuleInfo* _gwy_module_query__fft_filter_2d(void);
GwyModuleInfo* _gwy_module_query__fft_profile(void);
GwyModuleInfo* _gwy_module_query__fft_synth(void);
GwyModuleInfo* _gwy_module_query__fibre_synth(void);
GwyModuleInfo* _gwy_module_query__fit_shape(void);
GwyModuleInfo* _gwy_module_query__flatten_base(void);
GwyModuleInfo* _gwy_module_query__fraccor(void);
GwyModuleInfo* _gwy_module_query__fractal(void);
GwyModuleInfo* _gwy_module_query__gradient(void);
GwyModuleInfo* _gwy_module_query__grain_cross(void);
GwyModuleInfo* _gwy_module_query__grain_dist(void);
GwyModuleInfo* _gwy_module_query__grain_edge(void);
GwyModuleInfo* _gwy_module_query__grain_filter(void);
GwyModuleInfo* _gwy_module_query__grain_mark(void);
GwyModuleInfo* _gwy_module_query__grain_stat(void);
GwyModuleInfo* _gwy_module_query__grain_wshed(void);
GwyModuleInfo* _gwy_module_query__hough(void);
GwyModuleInfo* _gwy_module_query__immerse(void);
GwyModuleInfo* _gwy_module_query__indent_analyze(void);
GwyModuleInfo* _gwy_module_query__laplace(void);
GwyModuleInfo* _gwy_module_query__latsim(void);
GwyModuleInfo* _gwy_module_query__lat_synth(void);
GwyModuleInfo* _gwy_module_query__level(void);
GwyModuleInfo* _gwy_module_query__level_grains(void);
GwyModuleInfo* _gwy_module_query__linecorrect(void);
GwyModuleInfo* _gwy_module_query__linematch(void);
GwyModuleInfo* _gwy_module_query__lno_synth(void);
GwyModuleInfo* _gwy_module_query__local_contrast(void);
GwyModuleInfo* _gwy_module_query__logistic(void);
GwyModuleInfo* _gwy_module_query__mark_disconn(void);
GwyModuleInfo* _gwy_module_query__mark_with(void);
GwyModuleInfo* _gwy_module_query__maskcor(void);
GwyModuleInfo* _gwy_module_query__mask_distribute(void);
GwyModuleInfo* _gwy_module_query__mask_edt(void);
GwyModuleInfo* _gwy_module_query__mask_morph(void);
GwyModuleInfo* _gwy_module_query__mask_noisify(void);
GwyModuleInfo* _gwy_module_query__maskops(void);
GwyModuleInfo* _gwy_module_query__mcrop(void);
GwyModuleInfo* _gwy_module_query__measure_lattice(void);
GwyModuleInfo* _gwy_module_query__median_bg(void);
GwyModuleInfo* _gwy_module_query__merge(void);
GwyModuleInfo* _gwy_module_query__mfm_current(void);
GwyModuleInfo* _gwy_module_query__mfm_field(void);
GwyModuleInfo* _gwy_module_query__mfm_findshift(void);
GwyModuleInfo* _gwy_module_query__mfm_parallel(void);
GwyModuleInfo* _gwy_module_query__mfm_shift(void);
GwyModuleInfo* _gwy_module_query__neural(void);
GwyModuleInfo* _gwy_module_query__noise_synth(void);
GwyModuleInfo* _gwy_module_query__obj_synth(void);
GwyModuleInfo* _gwy_module_query__otsu_threshold(void);
GwyModuleInfo* _gwy_module_query__outliers(void);
GwyModuleInfo* _gwy_module_query__pat_synth(void);
GwyModuleInfo* _gwy_module_query__phase_synth(void);
GwyModuleInfo* _gwy_module_query__pid(void);
GwyModuleInfo* _gwy_module_query__pileup_synth(void);
GwyModuleInfo* _gwy_module_query__polylevel(void);
GwyModuleInfo* _gwy_module_query__polydistort(void);
GwyModuleInfo* _gwy_module_query__presentationops(void);
GwyModuleInfo* _gwy_module_query__psdf_logphi(void);
GwyModuleInfo* _gwy_module_query__psf(void);
GwyModuleInfo* _gwy_module_query__psf_fit(void);
GwyModuleInfo* _gwy_module_query__rank(void);
GwyModuleInfo* _gwy_module_query__roddeposit_synth(void);
GwyModuleInfo* _gwy_module_query__rotate(void);
GwyModuleInfo* _gwy_module_query__semsim(void);
GwyModuleInfo* _gwy_module_query__scale(void);
GwyModuleInfo* _gwy_module_query__scars(void);
GwyModuleInfo* _gwy_module_query__shade(void);
GwyModuleInfo* _gwy_module_query__slope_dist(void);
GwyModuleInfo* _gwy_module_query__sphere_revolve(void);
GwyModuleInfo* _gwy_module_query__stitch(void);
GwyModuleInfo* _gwy_module_query__straighten_path(void);
GwyModuleInfo* _gwy_module_query__threshold(void);
GwyModuleInfo* _gwy_module_query__tilt(void);
GwyModuleInfo* _gwy_module_query__tip_blind(void);
GwyModuleInfo* _gwy_module_query__tip_model(void);
GwyModuleInfo* _gwy_module_query__tipops(void);
GwyModuleInfo* _gwy_module_query__unrotate(void);
GwyModuleInfo* _gwy_module_query__volumize(void);
GwyModuleInfo* _gwy_module_query__volumize_layers(void);
GwyModuleInfo* _gwy_module_query__wave_synth(void);
GwyModuleInfo* _gwy_module_query__wpour_mark(void);
GwyModuleInfo* _gwy_module_query__xydenoise(void);
GwyModuleInfo* _gwy_module_query__xyzize(void);

static const GwyModuleRecord modules[] = {
  { _gwy_module_query__acf2d, "acf2d", },
  { _gwy_module_query__angle_dist, "angle_dist", },
  { _gwy_module_query__arithmetic, "arithmetic", },
  { _gwy_module_query__averaging, "averaging", },
  { _gwy_module_query__basicops, "basicops", },
  { _gwy_module_query__bdep_synth, "bdep_synth", },
  { _gwy_module_query__binning, "binning", },
  { _gwy_module_query__calcoefs_load, "calcoefs_load", },
  { _gwy_module_query__calcoefs_new, "calcoefs_new", },
  { _gwy_module_query__calcoefs_simple, "calcoefs_simple", },
  { _gwy_module_query__calcoefs_view, "calcoefs_view", },
  { _gwy_module_query__calibrate, "calibrate", },
  { _gwy_module_query__coerce, "coerce", },
  { _gwy_module_query__col_synth, "col_synth", },
  { _gwy_module_query__convolution_filter, "convolution_filter", },
  { _gwy_module_query__convolve, "convolve", },
  { _gwy_module_query__correct_affine, "correct_affine", },
  { _gwy_module_query__crosscor, "crosscor", },
  { _gwy_module_query__curvature, "curvature", },
  { _gwy_module_query__cwt, "cwt", },
  { _gwy_module_query__deposit_synth, "deposit_synth", },
  { _gwy_module_query__diff_synth, "diff_synth", },
  { _gwy_module_query__domain_synth, "domain_synth", },
  { _gwy_module_query__drift, "drift", },
  { _gwy_module_query__dwt, "dwt", },
  { _gwy_module_query__dwtanisotropy, "dwtanisotropy", },
  { _gwy_module_query__edge, "edge", },
  { _gwy_module_query__entropy, "entropy", },
  { _gwy_module_query__extend, "extend", },
  { _gwy_module_query__extract_path, "extract_path", },
  { _gwy_module_query__facet_level, "facet-level", },
  { _gwy_module_query__facet_analysis, "facet_analysis", },
  { _gwy_module_query__fbm_synth, "fbm_synth", },
  { _gwy_module_query__fft, "fft", },
  { _gwy_module_query__fft_filter_1d, "fft_filter_1d", },
  { _gwy_module_query__fft_filter_2d, "fft_filter_2d", },
  { _gwy_module_query__fft_profile, "fft_profile", },
  { _gwy_module_query__fft_synth, "fft_synth", },
  { _gwy_module_query__fibre_synth, "fibre_synth", },
  { _gwy_module_query__fit_shape, "fit-shape", },
  { _gwy_module_query__flatten_base, "flatten_base", },
  { _gwy_module_query__fraccor, "fraccor", },
  { _gwy_module_query__fractal, "fractal", },
  { _gwy_module_query__gradient, "gradient", },
  { _gwy_module_query__grain_cross, "grain_cross", },
  { _gwy_module_query__grain_dist, "grain_dist", },
  { _gwy_module_query__grain_edge, "grain_edge", },
  { _gwy_module_query__grain_filter, "grain_filter", },
  { _gwy_module_query__grain_mark, "grain_mark", },
  { _gwy_module_query__grain_stat, "grain_stat", },
  { _gwy_module_query__grain_wshed, "grain_wshed", },
  { _gwy_module_query__hough, "hough", },
  { _gwy_module_query__immerse, "immerse", },
  { _gwy_module_query__indent_analyze, "indent_analyze", },
  { _gwy_module_query__laplace, "laplace", },
  { _gwy_module_query__latsim, "latsim", },
  { _gwy_module_query__lat_synth, "lat_synth", },
  { _gwy_module_query__level, "level", },
  { _gwy_module_query__level_grains, "level_grains", },
  { _gwy_module_query__linecorrect, "linecorrect", },
  { _gwy_module_query__linematch, "linematch", },
  { _gwy_module_query__lno_synth, "lno_synth", },
  { _gwy_module_query__local_contrast, "local_contrast", },
  { _gwy_module_query__logistic, "logistic", },
  { _gwy_module_query__mark_disconn, "mark_disconn", },
  { _gwy_module_query__mark_with, "mark_with", },
  { _gwy_module_query__maskcor, "maskcor", },
  { _gwy_module_query__mask_distribute, "mask_distribute", },
  { _gwy_module_query__mask_edt, "mask_edt", },
  { _gwy_module_query__mask_morph, "mask_morph", },
  { _gwy_module_query__mask_noisify, "mask_noisify", },
  { _gwy_module_query__maskops, "maskops", },
  { _gwy_module_query__mcrop, "mcrop", },
  { _gwy_module_query__measure_lattice, "measure_lattice", },
  { _gwy_module_query__median_bg, "median-bg", },
  { _gwy_module_query__merge, "merge", },
  { _gwy_module_query__mfm_current, "mfm_current", },
  { _gwy_module_query__mfm_field, "mfm_field", },
  { _gwy_module_query__mfm_findshift, "mfm_findshift", },
  { _gwy_module_query__mfm_parallel, "mfm_parallel", },
  { _gwy_module_query__mfm_shift, "mfm_shift", },
  { _gwy_module_query__neural, "neural", },
  { _gwy_module_query__noise_synth, "noise_synth", },
  { _gwy_module_query__obj_synth, "obj_synth", },
  { _gwy_module_query__otsu_threshold, "otsu_threshold", },
  { _gwy_module_query__outliers, "outliers", },
  { _gwy_module_query__pat_synth, "pat_synth", },
  { _gwy_module_query__phase_synth, "phase_synth", },
  { _gwy_module_query__pid, "pid", },
  { _gwy_module_query__pileup_synth, "pileup_synth", },
  { _gwy_module_query__polylevel, "polylevel", },
  { _gwy_module_query__polydistort, "polydistort", },
  { _gwy_module_query__presentationops, "presentationops", },
  { _gwy_module_query__psdf_logphi, "psdf_logphi", },
  { _gwy_module_query__psf, "psf", },
  { _gwy_module_query__psf_fit, "psf-fit", },
  { _gwy_module_query__rank, "rank", },
  { _gwy_module_query__roddeposit_synth, "roddeposit_synth", },
  { _gwy_module_query__rotate, "rotate", },
  { _gwy_module_query__semsim, "semsim", },
  { _gwy_module_query__scale, "scale", },
  { _gwy_module_query__scars, "scars", },
  { _gwy_module_query__shade, "shade", },
  { _gwy_module_query__slope_dist, "slope_dist", },
  { _gwy_module_query__sphere_revolve, "sphere-revolve", },
  { _gwy_module_query__stitch, "stitch", },
  { _gwy_module_query__straighten_path, "straighten_path", },
  { _gwy_module_query__threshold, "threshold", },
  { _gwy_module_query__tilt, "tilt", },
  { _gwy_module_query__tip_blind, "tip_blind", },
  { _gwy_module_query__tip_model, "tip_model", },
  { _gwy_module_query__tipops, "tipops", },
  { _gwy_module_query__unrotate, "unrotate", },
  { _gwy_module_query__volumize, "volumize", },
  { _gwy_module_query__volumize_layers, "volumize_layers", },
  { _gwy_module_query__wave_synth, "wave_synth", },
  { _gwy_module_query__wpour_mark, "wpour_mark", },
  { _gwy_module_query__xydenoise, "xydenoise", },
  { _gwy_module_query__xyzize, "xyzize", },
  { NULL, NULL, },
};

static const GwyModuleRecord*
register_bundle(void)
{
    return modules;
}

==> gwyddion_2.52.orig.tar.xz: gwyddion-2.52/modules/process/process.c <==
/* This is a GENERATED file. */
#include <glib.h>
#include <libgwymodule/gwymodule.h>

static const GwyModuleRecord* register_bundle(void);

static GwyModuleInfo module_info = {
    GWY_MODULE_ABI_VERSION | GWY_MODULE_BUNDLE_FLAG,
    (GwyModuleRegisterFunc)&register_bundle,
    NULL, NULL, NULL, NULL, NULL,
};

GWY_MODULE_QUERY(module_info)

GwyModuleInfo* _gwy_module_query__acf2d(void);
GwyModuleInfo* _gwy_module_query__angle_dist(void);
GwyModuleInfo* _gwy_module_query__arithmetic(void);
GwyModuleInfo* _gwy_module_query__averaging(void);
GwyModuleInfo* _gwy_module_query__basicops(void);
GwyModuleInfo* _gwy_module_query__bdep_synth(void);
GwyModuleInfo* _gwy_module_query__binning(void);
GwyModuleInfo* _gwy_module_query__calcoefs_load(void);
GwyModuleInfo* _gwy_module_query__calcoefs_new(void);
GwyModuleInfo* _gwy_module_query__calcoefs_simple(void);
GwyModuleInfo* _gwy_module_query__calcoefs_view(void);
GwyModuleInfo* _gwy_module_query__calibrate(void);
GwyModuleInfo* _gwy_module_query__coerce(void);
GwyModuleInfo* _gwy_module_query__col_synth(void);
GwyModuleInfo* _gwy_module_query__convolution_filter(void);
GwyModuleInfo* _gwy_module_query__convolve(void);
GwyModuleInfo* _gwy_module_query__correct_affine(void);
GwyModuleInfo* _gwy_module_query__crosscor(void);
GwyModuleInfo* _gwy_module_query__curvature(void);
GwyModuleInfo* _gwy_module_query__cwt(void);
GwyModuleInfo* _gwy_module_query__deconvolve(void);
GwyModuleInfo* _gwy_module_query__deposit_synth(void);
GwyModuleInfo* _gwy_module_query__diff_synth(void);
GwyModuleInfo* _gwy_module_query__disc_synth(void);
GwyModuleInfo* _gwy_module_query__domain_synth(void);
GwyModuleInfo* _gwy_module_query__drift(void);
GwyModuleInfo* _gwy_module_query__dwt(void);
GwyModuleInfo* _gwy_module_query__dwtanisotropy(void);
GwyModuleInfo* _gwy_module_query__edge(void);
GwyModuleInfo* _gwy_module_query__entropy(void);
GwyModuleInfo* _gwy_module_query__extend(void);
GwyModuleInfo* _gwy_module_query__extract_path(void);
GwyModuleInfo* _gwy_module_query__facet_level(void);
GwyModuleInfo* _gwy_module_query__facet_analysis(void);
GwyModuleInfo* _gwy_module_query__fbm_synth(void);
GwyModuleInfo* _gwy_module_query__fft(void);
GwyModuleInfo* _gwy_module_query__fft_filter_1d(void);
GwyModuleInfo* _gwy_module_query__fft_filter_2d(void);
GwyModuleInfo* _gwy_module_query__psdf2d(void);
GwyModuleInfo* _gwy_module_query__fft_synth(void);
GwyModuleInfo* _gwy_module_query__fibre_synth(void);
GwyModuleInfo* _gwy_module_query__fit_shape(void);
GwyModuleInfo* _gwy_module_query__flatten_base(void);
GwyModuleInfo* _gwy_module_query__fraccor(void);
GwyModuleInfo* _gwy_module_query__fractal(void);
GwyModuleInfo* _gwy_module_query__gradient(void);
GwyModuleInfo* _gwy_module_query__grain_cross(void);
GwyModuleInfo* _gwy_module_query__grain_dist(void);
GwyModuleInfo* _gwy_module_query__grain_edge(void);
GwyModuleInfo* _gwy_module_query__grain_filter(void);
GwyModuleInfo* _gwy_module_query__grain_mark(void);
GwyModuleInfo* _gwy_module_query__grain_stat(void);
GwyModuleInfo* _gwy_module_query__grain_wshed(void);
GwyModuleInfo* _gwy_module_query__hertz(void);
GwyModuleInfo* _gwy_module_query__hough(void);
GwyModuleInfo* _gwy_module_query__immerse(void);
GwyModuleInfo* _gwy_module_query__indent_analyze(void);
GwyModuleInfo* _gwy_module_query__laplace(void);
GwyModuleInfo* _gwy_module_query__latsim(void);
GwyModuleInfo* _gwy_module_query__lat_synth(void);
GwyModuleInfo* _gwy_module_query__level(void);
GwyModuleInfo* _gwy_module_query__level_grains(void);
GwyModuleInfo* _gwy_module_query__linecorrect(void);
GwyModuleInfo* _gwy_module_query__linematch(void);
GwyModuleInfo* _gwy_module_query__lno_synth(void);
GwyModuleInfo* _gwy_module_query__local_contrast(void);
GwyModuleInfo* _gwy_module_query__logistic(void);
GwyModuleInfo* _gwy_module_query__mark_disconn(void);
GwyModuleInfo* _gwy_module_query__mark_with(void);
GwyModuleInfo* _gwy_module_query__maskcor(void);
GwyModuleInfo* _gwy_module_query__mask_distribute(void);
GwyModuleInfo* _gwy_module_query__mask_edt(void);
GwyModuleInfo* _gwy_module_query__mask_morph(void);
GwyModuleInfo* _gwy_module_query__mask_noisify(void);
GwyModuleInfo* _gwy_module_query__maskops(void);
GwyModuleInfo* _gwy_module_query__mcrop(void);
GwyModuleInfo* _gwy_module_query__measure_lattice(void);
GwyModuleInfo* _gwy_module_query__median_bg(void);
GwyModuleInfo* _gwy_module_query__merge(void);
GwyModuleInfo* _gwy_module_query__mfm_current(void);
GwyModuleInfo* _gwy_module_query__mfm_field(void);
GwyModuleInfo* _gwy_module_query__mfm_findshift(void);
GwyModuleInfo* _gwy_module_query__mfm_parallel(void);
GwyModuleInfo* _gwy_module_query__mfm_recalc(void);
GwyModuleInfo* _gwy_module_query__mfm_shift(void);
GwyModuleInfo* _gwy_module_query__neural(void);
GwyModuleInfo* _gwy_module_query__noise_synth(void);
GwyModuleInfo* _gwy_module_query__obj_synth(void);
GwyModuleInfo* _gwy_module_query__otsu_threshold(void);
GwyModuleInfo* _gwy_module_query__outliers(void);
GwyModuleInfo* _gwy_module_query__pat_synth(void);
GwyModuleInfo* _gwy_module_query__phase_synth(void);
GwyModuleInfo* _gwy_module_query__pid(void);
GwyModuleInfo* _gwy_module_query__pileup_synth(void);
GwyModuleInfo* _gwy_module_query__polylevel(void);
GwyModuleInfo* _gwy_module_query__polydistort(void);
GwyModuleInfo* _gwy_module_query__presentationops(void);
GwyModuleInfo* _gwy_module_query__psdf_logphi(void);
GwyModuleInfo* _gwy_module_query__psf(void);
GwyModuleInfo* _gwy_module_query__psf_fit(void);
GwyModuleInfo* _gwy_module_query__rank(void);
GwyModuleInfo* _gwy_module_query__roddeposit_synth(void);
GwyModuleInfo* _gwy_module_query__rotate(void);
GwyModuleInfo* _gwy_module_query__semsim(void);
GwyModuleInfo* _gwy_module_query__scale(void);
GwyModuleInfo* _gwy_module_query__scars(void);
GwyModuleInfo* _gwy_module_query__shade(void);
GwyModuleInfo* _gwy_module_query__slope_dist(void);
GwyModuleInfo* _gwy_module_query__sphere_revolve(void);
GwyModuleInfo* _gwy_module_query__stitch(void);
GwyModuleInfo* _gwy_module_query__straighten_path(void);
GwyModuleInfo* _gwy_module_query__threshold(void);
GwyModuleInfo* _gwy_module_query__tilt(void);
GwyModuleInfo* _gwy_module_query__tip_blind(void);
GwyModuleInfo* _gwy_module_query__tip_model(void);
GwyModuleInfo* _gwy_module_query__tipops(void);
GwyModuleInfo* _gwy_module_query__tipshape(void);
GwyModuleInfo* _gwy_module_query__unrotate(void);
GwyModuleInfo* _gwy_module_query__volumize(void);
GwyModuleInfo* _gwy_module_query__volumize_layers(void);
GwyModuleInfo* _gwy_module_query__wave_synth(void);
GwyModuleInfo* _gwy_module_query__wpour_mark(void);
GwyModuleInfo* _gwy_module_query__xydenoise(void);
GwyModuleInfo* _gwy_module_query__xyz_channels(void);
GwyModuleInfo* _gwy_module_query__xyzize(void);

static const GwyModuleRecord modules[] = {
  { _gwy_module_query__acf2d, "acf2d", },
  { _gwy_module_query__angle_dist, "angle_dist", },
  { _gwy_module_query__arithmetic, "arithmetic", },
  { _gwy_module_query__averaging, "averaging", },
  { _gwy_module_query__basicops, "basicops", },
  { _gwy_module_query__bdep_synth, "bdep_synth", },
  { _gwy_module_query__binning, "binning", },
  { _gwy_module_query__calcoefs_load, "calcoefs_load", },
  { _gwy_module_query__calcoefs_new, "calcoefs_new", },
  { _gwy_module_query__calcoefs_simple, "calcoefs_simple", },
  { _gwy_module_query__calcoefs_view, "calcoefs_view", },
  { _gwy_module_query__calibrate, "calibrate", },
  { _gwy_module_query__coerce, "coerce", },
  { _gwy_module_query__col_synth, "col_synth", },
  { _gwy_module_query__convolution_filter, "convolution_filter", },
  { _gwy_module_query__convolve, "convolve", },
  { _gwy_module_query__correct_affine, "correct_affine", },
  { _gwy_module_query__crosscor, "crosscor", },
  { _gwy_module_query__curvature, "curvature", },
  { _gwy_module_query__cwt, "cwt", },
  { _gwy_module_query__deconvolve, "deconvolve", },
  { _gwy_module_query__deposit_synth, "deposit_synth", },
  { _gwy_module_query__diff_synth, "diff_synth", },
  { _gwy_module_query__disc_synth, "disc_synth", },
  { _gwy_module_query__domain_synth, "domain_synth", },
  { _gwy_module_query__drift, "drift", },
  { _gwy_module_query__dwt, "dwt", },
  { _gwy_module_query__dwtanisotropy, "dwtanisotropy", },
  { _gwy_module_query__edge, "edge", },
  { _gwy_module_query__entropy, "entropy", },
  { _gwy_module_query__extend, "extend", },
  { _gwy_module_query__extract_path, "extract_path", },
  { _gwy_module_query__facet_level, "facet-level", },
  { _gwy_module_query__facet_analysis, "facet_analysis", },
  { _gwy_module_query__fbm_synth, "fbm_synth", },
  { _gwy_module_query__fft, "fft", },
  { _gwy_module_query__fft_filter_1d, "fft_filter_1d", },
  { _gwy_module_query__fft_filter_2d, "fft_filter_2d", },
  { _gwy_module_query__psdf2d, "psdf2d", },
  { _gwy_module_query__fft_synth, "fft_synth", },
  { _gwy_module_query__fibre_synth, "fibre_synth", },
  { _gwy_module_query__fit_shape, "fit-shape", },
  { _gwy_module_query__flatten_base, "flatten_base", },
  { _gwy_module_query__fraccor, "fraccor", },
  { _gwy_module_query__fractal, "fractal", },
  { _gwy_module_query__gradient, "gradient", },
  { _gwy_module_query__grain_cross, "grain_cross", },
  { _gwy_module_query__grain_dist, "grain_dist", },
  { _gwy_module_query__grain_edge, "grain_edge", },
  { _gwy_module_query__grain_filter, "grain_filter", },
  { _gwy_module_query__grain_mark, "grain_mark", },
  { _gwy_module_query__grain_stat, "grain_stat", },
  { _gwy_module_query__grain_wshed, "grain_wshed", },
  { _gwy_module_query__hertz, "hertz", },
  { _gwy_module_query__hough, "hough", },
  { _gwy_module_query__immerse, "immerse", },
  { _gwy_module_query__indent_analyze, "indent_analyze", },
  { _gwy_module_query__laplace, "laplace", },
  { _gwy_module_query__latsim, "latsim", },
  { _gwy_module_query__lat_synth, "lat_synth", },
  { _gwy_module_query__level, "level", },
  { _gwy_module_query__level_grains, "level_grains", },
  { _gwy_module_query__linecorrect, "linecorrect", },
  { _gwy_module_query__linematch, "linematch", },
  { _gwy_module_query__lno_synth, "lno_synth", },
  { _gwy_module_query__local_contrast, "local_contrast", },
  { _gwy_module_query__logistic, "logistic", },
  { _gwy_module_query__mark_disconn, "mark_disconn", },
  { _gwy_module_query__mark_with, "mark_with", },
  { _gwy_module_query__maskcor, "maskcor", },
  { _gwy_module_query__mask_distribute, "mask_distribute", },
  { _gwy_module_query__mask_edt, "mask_edt", },
  { _gwy_module_query__mask_morph, "mask_morph", },
  { _gwy_module_query__mask_noisify, "mask_noisify", },
  { _gwy_module_query__maskops, "maskops", },
  { _gwy_module_query__mcrop, "mcrop", },
  { _gwy_module_query__measure_lattice, "measure_lattice", },
  { _gwy_module_query__median_bg, "median-bg", },
  { _gwy_module_query__merge, "merge", },
  { _gwy_module_query__mfm_current, "mfm_current", },
  { _gwy_module_query__mfm_field, "mfm_field", },
  { _gwy_module_query__mfm_findshift, "mfm_findshift", },
  { _gwy_module_query__mfm_parallel, "mfm_parallel", },
  { _gwy_module_query__mfm_recalc, "mfm_recalc", },
  { _gwy_module_query__mfm_shift, "mfm_shift", },
  { _gwy_module_query__neural, "neural", },
  { _gwy_module_query__noise_synth, "noise_synth", },
  { _gwy_module_query__obj_synth, "obj_synth", },
  { _gwy_module_query__otsu_threshold, "otsu_threshold", },
  { _gwy_module_query__outliers, "outliers", },
  { _gwy_module_query__pat_synth, "pat_synth", },
  { _gwy_module_query__phase_synth, "phase_synth", },
  { _gwy_module_query__pid, "pid", },
  { _gwy_module_query__pileup_synth, "pileup_synth", },
  { _gwy_module_query__polylevel, "polylevel", },
  { _gwy_module_query__polydistort, "polydistort", },
  { _gwy_module_query__presentationops, "presentationops", },
  { _gwy_module_query__psdf_logphi, "psdf_logphi", },
  { _gwy_module_query__psf, "psf", },
  { _gwy_module_query__psf_fit, "psf-fit", },
  { _gwy_module_query__rank, "rank", },
  { _gwy_module_query__roddeposit_synth, "roddeposit_synth", },
  { _gwy_module_query__rotate, "rotate", },
  { _gwy_module_query__semsim, "semsim", },
  { _gwy_module_query__scale, "scale", },
  { _gwy_module_query__scars, "scars", },
  { _gwy_module_query__shade, "shade", },
  { _gwy_module_query__slope_dist, "slope_dist", },
  { _gwy_module_query__sphere_revolve, "sphere-revolve", },
  { _gwy_module_query__stitch, "stitch", },
  { _gwy_module_query__straighten_path, "straighten_path", },
  { _gwy_module_query__threshold, "threshold", },
  { _gwy_module_query__tilt, "tilt", },
  { _gwy_module_query__tip_blind, "tip_blind", },
  { _gwy_module_query__tip_model, "tip_model", },
  { _gwy_module_query__tipops, "tipops", },
  { _gwy_module_query__tipshape, "tipshape", },
  { _gwy_module_query__unrotate, "unrotate", },
  { _gwy_module_query__volumize, "volumize", },
  { _gwy_module_query__volumize_layers, "volumize_layers", },
  { _gwy_module_query__wave_synth, "wave_synth", },
  { _gwy_module_query__wpour_mark, "wpour_mark", },
  { _gwy_module_query__xydenoise, "xydenoise", },
  { _gwy_module_query__xyz_channels, "xyz_channels", },
  { _gwy_module_query__xyzize, "xyzize", },
  { NULL, NULL, },
};

static const GwyModuleRecord*
register_bundle(void)
{
    return modules;
}
